=======
Fitting
=======

Fitting
-------

For fitting a CTI model (composed from a ``CTI1D`` / ``CTI2D`` object) to a dataset.

.. currentmodule:: autocti

.. autosummary::
   :toctree: _autosummary
   :template: custom-class-template.rst
   :recursive:

   FitImagingCI
   FitDataset1D